@@ -3,17 +3,29 @@
 #' Summarise a \code{\link{Bchronology}} object
 #'
 #' @param object Output from a run of \code{\link{Bchronology}}
-#' @param type Type of output required. The default (quantiles) gives the quantiles of the ages for each position in \code{predictPositions} from \code{\link{Bchronology}}. The other options provide outlier probabilities, convergence diagnostics, accumulation rates and sedimentation rate
+#' @param type Type of output required. The default (quantiles) gives the quantiles of the ages for each position in \code{predictPositions} from \code{\link{Bchronology}}. The other options provide outlier probabilities, convergence diagnostics, accumulation rates, sedimentation rate, and positions of maximum age variance
 #' @param probs Probabilities (between 0 and 1) at which to summarise the predicted chronologies
 #' @param useExisting Whether to use the predicted chronologies/positions to calculate the sedimentation rate (if TRUE - default) or to re-create them based on a unit-scaled position grid (if FALSE). The latter will be a little bit slower but will provide better sedimentation rate estimates if the original positions are not on a unit scale (e.g. each cm)
+#' @param numPos The number of positions at which to provide the maximum variance
 #' @param ... Other arguments (not currently supported)
 #' @param digits Number of digits to report values
 #' @export
 #' 
 #' @seealso \code{\link{BchronCalibrate}}, \code{\link{Bchronology}} \code{\link{BchronRSL}}, \code{\link{BchronDensity}}, \code{\link{BchronDensityFast}}
 #'
-summary.BchronologyRun <-
-function(object,type=c('quantiles','outliers','convergence','sed_rate','acc_rate'),probs=c(0.025,0.1,0.5,0.9,0.975), useExisting = TRUE, ..., digits = max(3, getOption("digits")-3)) {
+summary.BchronologyRun =
+function(object,
+         type=c('quantiles', 
+                'outliers', 
+                'convergence', 
+                'sed_rate', 
+                'acc_rate',
+                'max_var'),
+         probs=c(0.025, 0.1, 0.5, 0.9, 0.975), 
+         useExisting = TRUE, 
+         numPos = 3,
+         ..., 
+         digits = max(3, getOption("digits")-3)) {
   type = match.arg(type)
 
   switch(type,
@@ -72,6 +84,18 @@ function(object,type=c('quantiles','outliers','convergence','sed_rate','acc_rate
       colnames(acc_rate_ci)[1] = 'age_grid'
       print(round(acc_rate_ci, digits=digits),row.names=FALSE)
       invisible(acc_rate_ci)
+    },
+    max_var = {
+      if(numPos==1) {
+        cat('Position with maximum age variance is: \n')
+      } else {
+        cat('Top',numPos, 'positions with maximum age variance are: \n')  
+      }
+      vars = apply(object$thetaPredict, 2, stats::var)
+      o = order(vars, decreasing = TRUE)
+      pos = object$predictPositions[o[1:numPos]]
+      cat(pos, '\n', sep = ' ')
+      invisible(pos)
     }
   )
 }
